@@ -49,7 +49,7 @@ class Constants:
 
 
 class FrontendUrl:
-    URL_BASE_COMMUNITY = '/tesis-asn/users/community/'
+    URL_BASE_COMMUNITY = '/usuarios/comunidad/'
 
 
 class DynamicFieldsSerializer(serializers.ModelSerializer):
